@@ -186,13 +186,13 @@ class S3Mixin(CloudMixin):
     AWS S3 functions usable by any module
     """
 
-    def get_s3_handle(self, cred=None):
+    def get_s3_handle(self, cred=None,client_kwargs=None):
         """
         Backward compatability. Calls s3_init_fshandle
         """
-        return self.s3_init_fshandle(cred)
+        return self.s3_init_fshandle(cred,client_kwargs=client_kwargs)
 
-    def s3_init_fshandle(self, cred=None):
+    def s3_init_fshandle(self, cred=None,client_kwargs=None):
         """
         Open a S3 connection. Takes credentials as an explicit
         argument or can pickup from 'aws_cred' attribute of self.
@@ -236,7 +236,8 @@ class S3Mixin(CloudMixin):
 
         return s3fs.S3FileSystem(
             key    = cred['access_key'],
-            secret = cred['secret_key']
+            secret = cred['secret_key'],
+            client_kwargs=client_kwargs
         )
 
 
