@@ -14,6 +14,7 @@ import traceback
 import s3fs
 from datetime import datetime
 import abc
+import jsonschema
 
 from ..lib.exceptions import *
 from ..lib import renderlib
@@ -167,11 +168,41 @@ class Node(metaclass=NodeMeta):
 
         """
 
+        self.datasets = []
+        """
+        Input and output datasets handled by this transform
+        """
+
+        self.args_schema = {}
+        """JSON Schema to validate the input args
+
+           See: https://python-jsonschema.readthedocs.io/en/latest/
+                https://json-schema.org/
+
+            self.args_schema = {
+                "type": "object",
+                "properties": {
+                    "name": {
+                         "type": "string"
+                         "description": "Name of the dataset"
+                     },
+                    "count": {
+                         "type": "number"
+                         "description": "Threshold"
+                     }
+                     ...
+                 }
+                 "required": ["name", "count"]
+                }
+            }
+
+        """
+
         self.supported_extra_args = []
         """Extra arguments that can be passed on the commandline to
         the module.
 
-            self.extra_args = [
+            self.supported_extra_args = [
                 {
                     "name": "jobid",
                     "description": "Export JobID",
@@ -184,16 +215,14 @@ class Node(metaclass=NodeMeta):
             ]
 
         """
-        data_root = self.get_file("%(data_root)s/%(name)s", extra={
-            'name': self.name
-        })
+        data_root = self.get_file("%(data_root)s")
 
         self.testdata = self.get_testdata
         """dict: Test data to be used for testing module
 
-        The default structure is instantiated by self.get_testdata. Each 
-        of the elements (e.g., conf) can be specified by over-riding 
-        corresponding method (e.g., self.get_testdata_conf). Such 
+        The default structure is instantiated by self.get_testdata. Each
+        of the elements (e.g., conf) can be specified by over-riding
+        corresponding method (e.g., self.get_testdata_conf). Such
         functions are supported for conf, args, global, data.
 
         It has the form::
@@ -449,7 +478,7 @@ class Node(metaclass=NodeMeta):
     def get_testdata_data(self):
         """
         Get 'data' element of test data. This specifies
-        what dataframes have to be loaded to test this 
+        what dataframes have to be loaded to test this
         transform.
 
         Returns
@@ -458,7 +487,7 @@ class Node(metaclass=NodeMeta):
 
         Example::
 
-          return { 
+          return {
                 'article': {
                     'filename': 'test.csv',
                     'transform': 'Core',
@@ -912,7 +941,7 @@ class Node(metaclass=NodeMeta):
     def validate_args(self, what, state):
         """
         Validate user-specified args for both content and
-        structure.
+        structure against args_schema.
 
         Args:
             what (str): "args"
@@ -927,7 +956,15 @@ class Node(metaclass=NodeMeta):
              Exception ("Validation error")
 
         """
-        pass
+        # Validate the schema
+        try:
+            jsonschema.validate(self.args, self.args_schema)
+        except:
+            logger.exception("Invalid/insufficient arguments. Doesnt match schema",
+                             extra={
+                                 'transform': self.name
+                             })
+
 
     def validate_input(self, what, state):
         """
@@ -1572,7 +1609,7 @@ class Transform(Node):
         """
         Validate outputs generated by the transform
         """
-        raise Exception("Transform module not overriding this check")
+        pass
 
 class Model(Transform):
     """
